@@ -6,7 +6,7 @@ use warnings;
 
 use Scalar::Util qw(blessed);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Tree::Simple::Manager::Index;
 use Tree::Simple::Manager::Exceptions;
@@ -52,7 +52,7 @@ sub _init {
         
         # by default we use our Index module
         
-        my $tree_index_module;;
+        my $tree_index_module;
         if (exists $config->{tree_index}) {
             ($config->{tree_index}->isa('Tree::Simple::Manager::Index')) 
                 || throw Tree::Simple::Manager::IncorrectObjectType "the 'tree_index' must be a subclass of Tree::Simple::Manager::Index";
@@ -114,7 +114,12 @@ sub _loadTree {
     my $tree;
     eval {
         my $tp = Tree::Parser->new($config->{tree_root});
+        
+        $tp->setFileEncoding($config->{tree_file_encoding}) 
+            if exists $config->{tree_file_encoding};
+            
         $tp->setInput($config->{tree_file_path});
+        
         if (exists $config->{tree_parse_filter}) {
             (ref($config->{tree_parse_filter}) eq 'CODE')
                 || throw Tree::Simple::Manager::IncorrectObjectType "a 'tree_parse_filter' must be a code ref";
@@ -363,6 +368,11 @@ This is a HASH ref whose keys are tree ids (fetchable through
 Tree::Simple::Manager::Index) and then accompanying metadata (which 
 can pretty much be anything actually). 
 
+=item I<tree_file_encoding>
+
+This will pass on the encoding type to be used when reading in the 
+file with Tree::Parser.
+
 =back
 
 =item B<getTreeList>
